SoMaJo
======

SoMaJo is a state-of-the-art tokenizer for German web and social media
texts that won the `EmpiriST 2015 shared task
<https://sites.google.com/site/empirist2015/>`_ on automatic
linguistic annotation of computer-mediated communication / social
media. As such, it is particularly well-suited to perform tokenization
on all kinds of written discourse, for example chats, forums, wiki
talk pages, tweets, blog comments, social networks, SMS and WhatsApp
dialogues.

More detailed documentation is available `here
<https://github.com/tsproisl/SoMaJo>`_.
